@@ -273,51 +273,52 @@ class account():
                     rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
             data += rtdata
             for x in data:
-                 if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
-                     print "Tweet already in store"
-                 else:
-                     if (self.accountdata.last_id != None):
-                        if (x.id == self.accountdata.last_id):
-                            continue
-                     if (None != x.in_reply_to_status_id):
-                        print "reply to " + x.in_reply_to_screen_name
-                        #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
-                        reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
+                 if x != None:
+                     if (self.checkStoreForTweet(long(x.id),self.tweetstore)):
+                         print "Tweet already in store"
                      else:
-                        reply_to = ""
-
-                     reply_to = reply_to.replace("&", "&amp;")
-                     #need to store id numbers for oldest/newest
-                     if self.accountdata.last_id == None:
-                        self.accountdata.last_id = x.id
-                     else:
-                        #if we have an id stored, check if this one is 'newer' if so then store it
-                        if long(self.accountdata.last_id) < long(x.id):
+                         if (self.accountdata.last_id != None):
+                            if (x.id == self.accountdata.last_id):
+                                continue
+                         if (None != x.in_reply_to_status_id):
+                            print "reply to " + x.in_reply_to_screen_name
+                            #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
+                            reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
+                         else:
+                            reply_to = ""
+    
+                         reply_to = reply_to.replace("&", "&amp;")
+                         #need to store id numbers for oldest/newest
+                         if self.accountdata.last_id == None:
                             self.accountdata.last_id = x.id
-
-                     #also want to track the oldest we get hold of
-                     if self.accountdata.oldest_id == None:
-                        self.accountdata.oldest_id = x.id
-                     else:
-                        if long(self.accountdata.oldest_id) > long(x.id):
+                         else:
+                            #if we have an id stored, check if this one is 'newer' if so then store it
+                            if long(self.accountdata.last_id) < long(x.id):
+                                self.accountdata.last_id = x.id
+    
+                         #also want to track the oldest we get hold of
+                         if self.accountdata.oldest_id == None:
                             self.accountdata.oldest_id = x.id
-                     #strip the source app name from the url
-                     source = self.getSourceAppname(x.source)
-                     text = self.escapeText(x.text)
-                     text = self.controller.expandBitlyUrls(text)
-                     if (x.GetPlace() !=None):
-                         place = x.GetPlace().name
-                     else:
-                         place=None
-                     
-                     pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                     created_at = self.parse_time(x.created_at)
-                     formatted_ts = self.format_timestamp(created_at)
-                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
-                     longid= long(x.id)
-                     self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
-                     
-                     receive_count = receive_count + 1
+                         else:
+                            if long(self.accountdata.oldest_id) > long(x.id):
+                                self.accountdata.oldest_id = x.id
+                         #strip the source app name from the url
+                         source = self.getSourceAppname(x.source)
+                         text = self.escapeText(x.text)
+                         text = self.controller.expandBitlyUrls(text)
+                         if (x.GetPlace() !=None):
+                             place = x.GetPlace().name
+                         else:
+                             place=None
+                         
+                         pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
+                         created_at = self.parse_time(x.created_at)
+                         formatted_ts = self.format_timestamp(created_at)
+                         formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
+                         longid= long(x.id)
+                         self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                         
+                         receive_count = receive_count + 1
 
             if (receive_count > 0):
                 note = osso.SystemNote(self.osso_c)
