@@ -1115,7 +1115,7 @@ class Witter():
             #self.ui.window.setActiveWindow()
 
          if method == 'open_dm':
-            self.ui.switchViewTo(self.ui.treeview,"direct")
+            self.ui.toggleviewto("direct")
             self.ui.window.show()
             #self.ui.window.fullscreen()
             
@@ -1124,8 +1124,8 @@ class Witter():
     def _on_orientation_signal(self, orientation, stand, face, x, y, z):
          
          if (self.ui.activeWindow.get_is_topmost()):
-             if ((orientation == 'portrait') & (self.ui.orientation != 'Landscape') ):
-                print "switching to portrait"
+             if ((orientation == 'portrait') & (self.ui.current_orientation == 'landscape') ):
+                print "switching to portrait from " + self.ui.current_orientation
                 #self.ui.orientation=orientation
                 #self.ui.cell.set_property('wrap-width', 400)
                 
@@ -1137,8 +1137,8 @@ class Witter():
                     self.ui.toggleviewto(self.ui.activeWin)
                 self.ui.current_orientation = 'portrait'
                 
-             if ((orientation == 'landscape') & (self.ui.orientation != 'Portrait')):
-                print "switching to landscape"
+             if ((orientation == 'landscape') & (self.ui.current_orientation == 'portrait')):
+                print "switching to landscape from " + self.ui.current_orientation
                 #self.ui.orientation=orientation
                 #self.ui.cell.set_property('wrap-width', 730)
                 
